@@ -306,8 +306,8 @@ ascii_to_vector(char *line, size_t len, int *nsamples, int *nones, VECTOR *ret)
 	if (*nsamples == 0)
 		*nsamples = i;
 	else if (*nsamples != i) {
-		fprintf(stderr, "Wrong number of samples. Expected %d got %d\n",
-		    *nsamples, i);
+//		fprintf(stderr, "Wrong number of samples. Expected %d got %d\n",
+//		    *nsamples, i);
 		/* free(buf); */
 		buf = NULL;
 	}
@@ -885,68 +885,68 @@ rule_ff1(VECTOR v, int start_pos, int len)
 #endif
 }
 
-void
-ruleset_print(ruleset_t *rs, rule_t *rules, int detail)
-{
-	int i, n;
-	int total_support;
+//void
+//ruleset_print(ruleset_t *rs, rule_t *rules, int detail)
+//{
+//	int i, n;
+//	int total_support;
+//
+//	printf("%d rules %d samples\n", rs->n_rules, rs->n_samples);
+//	n = (rs->n_samples + BITS_PER_ENTRY - 1) / BITS_PER_ENTRY;
+//
+//	total_support = 0;
+//	for (i = 0; i < rs->n_rules; i++) {
+//		rule_print(rules, rs->rules[i].rule_id, n, detail);
+//		ruleset_entry_print(rs->rules + i, n, detail);
+//		total_support += rs->rules[i].ncaptured;
+//	}
+//	printf("Total Captured: %d\n", total_support);
+//}
 
-	printf("%d rules %d samples\n", rs->n_rules, rs->n_samples);
-	n = (rs->n_samples + BITS_PER_ENTRY - 1) / BITS_PER_ENTRY;
+//void
+//ruleset_entry_print(ruleset_entry_t *re, int n, int detail)
+//{
+//	printf("%d captured; \n", re->ncaptured);
+//	if (detail)
+//		rule_vector_print(re->captures, n);
+//}
 
-	total_support = 0;
-	for (i = 0; i < rs->n_rules; i++) {
-		rule_print(rules, rs->rules[i].rule_id, n, detail);
-		ruleset_entry_print(rs->rules + i, n, detail);
-		total_support += rs->rules[i].ncaptured;
-	}
-	printf("Total Captured: %d\n", total_support);
-}
+//void
+//rule_print(rule_t *rules, int ndx, int n, int detail)
+//{
+//	rule_t *r;
+//
+//	r = rules + ndx;
+//	printf("RULE %d: ( %s ), support=%d, card=%d:",
+//	    ndx, r->features, r->support, r->cardinality);
+//	if (detail)
+//		rule_vector_print(r->truthtable, n);
+//}
 
-void
-ruleset_entry_print(ruleset_entry_t *re, int n, int detail)
-{
-	printf("%d captured; \n", re->ncaptured);
-	if (detail)
-		rule_vector_print(re->captures, n);
-}
+//void
+//rule_vector_print(VECTOR v, int n)
+//{
+//#ifdef GMP
+//	mpz_out_str(stdout, 16, v);
+//	printf("\n");
+//#else
+//	int i;
+//	for (i = 0; i < n; i++)
+//		printf("0x%lx ", v[i]);
+//	printf("\n");
+//#endif
+//
+//}
 
-void
-rule_print(rule_t *rules, int ndx, int n, int detail)
-{
-	rule_t *r;
-
-	r = rules + ndx;
-	printf("RULE %d: ( %s ), support=%d, card=%d:",
-	    ndx, r->features, r->support, r->cardinality);
-	if (detail)
-		rule_vector_print(r->truthtable, n);
-}
-
-void
-rule_vector_print(VECTOR v, int n)
-{
-#ifdef GMP
-	mpz_out_str(stdout, 16, v);
-	printf("\n");
-#else
-	int i;
-	for (i = 0; i < n; i++)
-		printf("0x%lx ", v[i]);
-	printf("\n");
-#endif
-
-}
-
-void
-rule_print_all(rule_t *rules, int nrules, int nsamples)
-{
-	int i, n;
-
-	n = (nsamples + BITS_PER_ENTRY - 1) / BITS_PER_ENTRY;
-	for (i = 0; i < nrules; i++)
-		rule_print(rules, i, n, 1);
-}
+//void
+//rule_print_all(rule_t *rules, int nrules, int nsamples)
+//{
+//	int i, n;
+//
+//	n = (nsamples + BITS_PER_ENTRY - 1) / BITS_PER_ENTRY;
+//	for (i = 0; i < nrules; i++)
+//		rule_print(rules, i, n, 1);
+//}
 
 /*
  * Return 0 if bit e is not set in vector v; return non-0 otherwise.
